r22476 - gnucash/trunk - Change of mind. Use scm instead of vcs.

Geert Janssens gjanssens at code.gnucash.org
Thu Nov 1 06:35:34 EDT 2012


Author: gjanssens
Date: 2012-11-01 06:35:34 -0400 (Thu, 01 Nov 2012)
New Revision: 22476
Trac: http://svn.gnucash.org/trac/changeset/22476

Added:
   gnucash/trunk/util/gnc-scm-info
Removed:
   gnucash/trunk/util/gnc-vcs-info
Modified:
   gnucash/trunk/Makefile.am
   gnucash/trunk/configure.ac
   gnucash/trunk/intl-scm/Makefile.am
   gnucash/trunk/packaging/win32/build_package.sh
   gnucash/trunk/packaging/win32/build_package_git.sh
   gnucash/trunk/packaging/win32/defaults.sh
   gnucash/trunk/packaging/win32/dist-impl.sh
   gnucash/trunk/packaging/win32/install-impl.sh
   gnucash/trunk/src/Makefile.am
   gnucash/trunk/src/app-utils/Makefile.am
   gnucash/trunk/src/bin/gnucash-bin.c
   gnucash/trunk/src/core-utils/Makefile.am
   gnucash/trunk/src/engine/Makefile.am
   gnucash/trunk/src/gnc-module/Makefile.am
   gnucash/trunk/src/gnc-module/test/mod-bar/Makefile.am
   gnucash/trunk/src/gnc-module/test/mod-baz/Makefile.am
   gnucash/trunk/src/gnc-module/test/mod-foo/Makefile.am
   gnucash/trunk/src/gnc/main.cpp
   gnucash/trunk/src/gnome-utils/Makefile.am
   gnucash/trunk/src/gnome-utils/gnc-main-window.c
   gnucash/trunk/src/gnome-utils/gnc-splash.c
   gnucash/trunk/src/gnome/Makefile.am
   gnucash/trunk/src/html/Makefile.am
   gnucash/trunk/src/optional/python-bindings/Makefile.am
   gnucash/trunk/src/pixmaps/Makefile.am
   gnucash/trunk/src/report/report-gnome/Makefile.am
   gnucash/trunk/src/report/report-system/Makefile.am
   gnucash/trunk/src/test-core/Makefile.am
Log:
Change of mind. Use scm instead of vcs.

scm is the modern term. vcs is rather used to refer to archaic systems
such as cvs and older. I wish I remembered this before my previous
commit. Oh well...

Modified: gnucash/trunk/Makefile.am
===================================================================
--- gnucash/trunk/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -77,7 +77,7 @@
   intltool-extract.in \
   intltool-merge.in \
   intltool-update.in \
-  util/gnc-vcs-info
+  util/gnc-scm-info
 
 ## We borrow guile's convention and use @-...-@ as the substitution
 ## brackets here, instead of the usual @... at .  This prevents autoconf
@@ -186,7 +186,7 @@
 SVN = svn
 XSLTPROC = xsltproc
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 # This rule will generate a ChangeLog of gnucash/trunk commits, plus
 # all additional branches that are added in
 # ./macros/svn2cl.xsl. (FIXME: Is the dependency on NEWS really a good

Modified: gnucash/trunk/configure.ac
===================================================================
--- gnucash/trunk/configure.ac	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/configure.ac	2012-11-01 10:35:34 UTC (rev 22476)
@@ -175,38 +175,38 @@
 fi
 
 # test whether we are building directly from svn/svk/git/bzr
-${srcdir}/util/gnc-vcs-info -r ${srcdir} >/dev/null 2>&1
-if test $? = 0 -o "x${BUILDING_FROM_VCS}" = "xyes" ; then
-  BUILDING_FROM_VCS=yes
+${srcdir}/util/gnc-scm-info -r ${srcdir} >/dev/null 2>&1
+if test $? = 0 -o "x${BUILDING_FROM_SCM}" = "xyes" ; then
+  BUILDING_FROM_SCM=yes
 
   # We need at least version 1.3.31 of SWIG because
   # that's when SWIG doesn't barf on the "inline" keyword in C headers anymore
   AC_PROG_SWIG(1.3.31)
 else
-  BUILDING_FROM_VCS=no
-  # Make sure we've got swig-runtime.h and gnc-vcs-info.h
+  BUILDING_FROM_SCM=no
+  # Make sure we've got swig-runtime.h and gnc-scm-info.h
   AC_CHECK_FILE(${srcdir}/src/swig-runtime.h, [],
     [AC_MSG_ERROR([
 
 It looks like you are NOT building from Subversion, svk, git or bzr
 but I cannot find swig-runtime.h.  Check your PATH and make sure
-we can find gnc-vcs-info in your PATH!
+we can find gnc-scm-info in your PATH!
 Either that or contact gnucash-devel at gnucash.org because
 the tarball you downloaded is broken.
 
     ])])
-  AC_CHECK_FILE(${srcdir}/src/core-utils/gnc-vcs-info.h, [],
+  AC_CHECK_FILE(${srcdir}/src/core-utils/gnc-scm-info.h, [],
     [AC_MSG_ERROR([
 
 It looks like you are NOT building from Subversion, svk, git or bzr
-but I cannot find gnc-vcs-info.h.  Check your PATH and make sure
-we can find gnc-vcs-info in your PATH!
+but I cannot find gnc-scm-info.h.  Check your PATH and make sure
+we can find gnc-scm-info in your PATH!
 Either that or contact gnucash-devel at gnucash.org because
 the tarball you downloaded is broken.
 
     ])])
 fi
-AM_CONDITIONAL(BUILDING_FROM_VCS, test "x$BUILDING_FROM_VCS" = "xyes")
+AM_CONDITIONAL(BUILDING_FROM_SCM, test "x$BUILDING_FROM_SCM" = "xyes")
 
 # Build dir adjustments
 AM_CONDITIONAL(GNUCASH_SEPARATE_BUILDDIR, test "x${srcdir}" != "x.")
@@ -1112,7 +1112,7 @@
   #warnFLAGS="${warnFLAGS} -Werror-implicit-function-declaration" # In -Wall
 
   # error-on-warning should not be active in (stable) release tarballs
-  if test "x$BUILDING_FROM_VCS" = "xyes"
+  if test "x$BUILDING_FROM_SCM" = "xyes"
   then
     # This code is from svn/svk/git/bzr, so enable error-on-warning
     error_on_warning_as_default="yes"

Modified: gnucash/trunk/intl-scm/Makefile.am
===================================================================
--- gnucash/trunk/intl-scm/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/intl-scm/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -12,7 +12,7 @@
 
 SCMFILES = $(shell find ${abs_top_srcdir}/src -name test -prune -o -name '*.scm' -print | sort)
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 # This needs to be generated in srcdir
 guile-strings.c: $(SCMFILES)
 	rm -f guile-strings.c

Modified: gnucash/trunk/packaging/win32/build_package.sh
===================================================================
--- gnucash/trunk/packaging/win32/build_package.sh	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/packaging/win32/build_package.sh	2012-11-01 10:35:34 UTC (rev 22476)
@@ -65,12 +65,12 @@
 _BUILD_UDIR=`unix_path $BUILD_DIR`
 _GNUCASH_UDIR=`unix_path $GNUCASH_DIR`
 PKG_VERSION=`grep PACKAGE_VERSION ${_BUILD_UDIR}/config.h | cut -d" " -f3 | cut -d\" -f2 `
-GNC_VCS_REV=`grep GNUCASH_VCS_REV ${_BUILD_UDIR}/src/core-utils/gnc-vcs-info.h | cut -d" " -f3 | cut -d\" -f2 `
+GNUCASH_SCM_REV=`grep GNUCASH_SCM_REV ${_BUILD_UDIR}/src/core-utils/gnc-scm-info.h | cut -d" " -f3 | cut -d\" -f2 `
 
 # Choose the output filename based on our "build_from_tarball" setting
 # Make sure this logic matches the logic in dist.sh!
 if [ "$BUILD_FROM_TARBALL" = "no" ]; then
-  SETUP_FILENAME="gnucash-${PKG_VERSION}-svn-r${GNC_VCS_REV}-setup.exe"
+  SETUP_FILENAME="gnucash-${PKG_VERSION}-svn-r${GNUCASH_SCM_REV}-setup.exe"
 else
   SETUP_FILENAME="gnucash-${PKG_VERSION}-setup.exe"
 fi

Modified: gnucash/trunk/packaging/win32/build_package_git.sh
===================================================================
--- gnucash/trunk/packaging/win32/build_package_git.sh	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/packaging/win32/build_package_git.sh	2012-11-01 10:35:34 UTC (rev 22476)
@@ -23,7 +23,7 @@
 . functions.sh
 . defaults.sh
 
-tag="${1:-$GNC_VCS_REV}"
+tag="${1:-$GNUCASH_SCM_REV}"
 
 # Determine where to upload to
 # NOTE: this assumes "tag" to be either a tag or a branch, not a
@@ -69,7 +69,7 @@
 _BUILD_UDIR=`unix_path $BUILD_DIR`
 _GNUCASH_UDIR=`unix_path $GNUCASH_DIR`
 PKG_VERSION=`grep PACKAGE_VERSION ${_BUILD_UDIR}/config.h | cut -d" " -f3 | cut -d\" -f2 `
-REVISION=`grep GNUCASH_VCS_REV ${_BUILD_UDIR}/src/core-utils/gnc-vcs-info.h | cut -d" " -f3 | cut -d\" -f2 `
+REVISION=`grep GNUCASH_SCM_REV ${_BUILD_UDIR}/src/core-utils/gnc-scm-info.h | cut -d" " -f3 | cut -d\" -f2 `
 
 # Choose the output filename based on our "build_from_tarball" setting
 # Make sure this logic matches the logic in dist.sh!

Modified: gnucash/trunk/packaging/win32/defaults.sh
===================================================================
--- gnucash/trunk/packaging/win32/defaults.sh	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/packaging/win32/defaults.sh	2012-11-01 10:35:34 UTC (rev 22476)
@@ -42,11 +42,11 @@
 
     set_default REPOS_TYPE "git"
     if [ "$REPOS_TYPE" = "git" ]; then
-      set_default GNC_VCS_REV "trunk"
+      set_default GNUCASH_SCM_REV "trunk"
       set_default REPOS_URL "git://github.com/Gnucash/gnucash.git"
     elif [ "$REPOS_TYPE" = "svn" ]; then
       # latest revision that should compile, use HEAD or vwxyz
-      set_default GNC_VCS_REV "HEAD"
+      set_default GNUCASH_SCM_REV "HEAD"
       set_default REPOS_URL "http://svn.gnucash.org/repo/gnucash/trunk"
     fi
 fi
@@ -409,11 +409,11 @@
 set_default DOCBOOK_XSL_URL "$SF_MIRROR/docbook/docbook-xsl-1.76.1.zip"
 set_default DOCBOOK_DTD_URL "http://www.oasis-open.org/docbook/xml/4.1.2/docbkx412.zip"
 if [ "$REPOS_TYPE" = "git" ]; then
-  set_default DOCS_VCS_REV "trunk"
+  set_default DOCS_SCM_REV "trunk"
   set_default DOCS_URL "git://github.com/Gnucash/gnucash-docs.git"
 elif [ "$REPOS_TYPE" = "svn" ]; then
   # latest revision that should compile, use HEAD or vwxyz
-  set_default DOCS_VCS_REV "HEAD"
+  set_default DOCS_SCM_REV "HEAD"
   set_default DOCS_URL "http://svn.gnucash.org/repo/gnucash-docs/trunk"
 fi
 set_default UPDATE_DOCS yes

Modified: gnucash/trunk/packaging/win32/dist-impl.sh
===================================================================
--- gnucash/trunk/packaging/win32/dist-impl.sh	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/packaging/win32/dist-impl.sh	2012-11-01 10:35:34 UTC (rev 22476)
@@ -297,7 +297,7 @@
     if [ "$BUILD_FROM_TARBALL" = "no" ]; then
         # And changing output filename
         PKG_VERSION=`grep PACKAGE_VERSION ${_BUILD_UDIR}/config.h | cut -d" " -f3 | cut -d\" -f2 `
-        REVISION=`grep GNUCASH_VCS_REV ${_BUILD_UDIR}/src/core-utils/gnc-vcs-info.h | cut -d" " -f3 | cut -d\" -f2 `
+        REVISION=`grep GNUCASH_SCM_REV ${_BUILD_UDIR}/src/core-utils/gnc-scm-info.h | cut -d" " -f3 | cut -d\" -f2 `
         if [ "$REPOS_TYPE" = "svn" ]; then
           SETUP_FILENAME="gnucash-${PKG_VERSION}-${REPOS_TYPE}-r${REVISION}-setup.exe"
         else

Modified: gnucash/trunk/packaging/win32/install-impl.sh
===================================================================
--- gnucash/trunk/packaging/win32/install-impl.sh	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/packaging/win32/install-impl.sh	2012-11-01 10:35:34 UTC (rev 22476)
@@ -1582,10 +1582,10 @@
     if [ "$UPDATE_DOCS" = "yes" ]; then
         if [ -x .svn ]; then
             setup "Docs - Update repository (svn)"
-            svn up -r $DOCS_VCS_REV
+            svn up -r $DOCS_SCM_REV
         else
             setup "Docs - Checkout repository (svn)"
-            svn co -r $DOCS_VCS_REV $DOCS_URL .
+            svn co -r $DOCS_SCM_REV $DOCS_URL .
         fi
     fi
 }
@@ -1599,7 +1599,7 @@
         else
             setup "Docs - Checkout repository (git)"
             $GIT_CMD clone $DOCS_URL .
-            $GIT_CMD checkout $DOCS_VCS_REV
+            $GIT_CMD checkout $DOCS_SCM_REV
         fi
     fi
 }

Modified: gnucash/trunk/src/Makefile.am
===================================================================
--- gnucash/trunk/src/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -53,7 +53,7 @@
 
 noinst_DATA = gnc-test-env
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 swig-runtime.h:
 	$(SWIG) -guile -external-runtime $@
 endif

Modified: gnucash/trunk/src/app-utils/Makefile.am
===================================================================
--- gnucash/trunk/src/app-utils/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/app-utils/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -93,7 +93,7 @@
   ${GUILE_LIBS} \
   ${GLIB_LIBS}
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 swig-app-utils-guile.c: app-utils.i ${top_srcdir}/src/base-typemaps.i
 	$(SWIG) -guile $(SWIG_ARGS) -Linkage module \
 	-I${top_srcdir}/src -o $@ $<

Modified: gnucash/trunk/src/bin/gnucash-bin.c
===================================================================
--- gnucash/trunk/src/core-utils/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/core-utils/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -40,7 +40,7 @@
   gnc-path.h \
   gnc-uri-utils.h
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 swig-core-utils-guile.c: core-utils.i ${top_srcdir}/src/base-typemaps.i
 	$(SWIG) -guile $(SWIG_ARGS) -Linkage module \
 	-I${top_srcdir}/src -o $@ $<
@@ -107,7 +107,7 @@
 
 noinst_DATA = .scm-links
 BUILT_SOURCES = gncla-dir.h gnc-version.h
-EXTRA_DIST = $(gncmod_DATA) core-utils.i gncla-dir.h.in gnc-vcs-info.h
+EXTRA_DIST = $(gncmod_DATA) core-utils.i gncla-dir.h.in gnc-scm-info.h
 clean-local:
 	rm -rf gnucash
 
@@ -136,37 +136,37 @@
 	-cmp -s _gnc-version.h gnc-version.h || cp _gnc-version.h gnc-version.h
 	-rm -f _gnc-version.h
 
-_gnc-version.h: gnc-vcs-info.h Makefile
+_gnc-version.h: gnc-scm-info.h Makefile
 	@echo "/* Autogenerated. Do not change. */"   > _gnc-version.h
 	@echo "#ifndef GNC_VERSION_H"                >> _gnc-version.h
 	@echo "#define GNC_VERSION_H"                >> _gnc-version.h
 	@echo ""                                     >> _gnc-version.h
-	@vcs_info=`${top_srcdir}/util/gnc-vcs-info -t ${top_srcdir}` ; \
+	@scm_info=`${top_srcdir}/util/gnc-scm-info -t ${top_srcdir}` ; \
 	if [ $$? = 0 ] ; then \
-		echo "#define GNUCASH_VCS \"$$vcs_info\"" >> _gnc-version.h ; \
+		echo "#define GNUCASH_SCM \"$$scm_info\"" >> _gnc-version.h ; \
 	fi
 	@echo "#define GNUCASH_BUILD_DATE \"`date +%Y-%m-%d`\"" >> _gnc-version.h
-	@echo "#include \"gnc-vcs-info.h\""          >> _gnc-version.h
+	@echo "#include \"gnc-scm-info.h\""          >> _gnc-version.h
 	@echo "#endif"                               >> _gnc-version.h
 
-gnc-vcs-info.h: _gnc-vcs-info.h
-	-if [ ! -f gnc-vcs-info.h ]; then cp _gnc-vcs-info.h gnc-vcs-info.h; fi
-	-cmp -s _gnc-vcs-info.h gnc-vcs-info.h || cp _gnc-vcs-info.h gnc-vcs-info.h
-	-rm -f _gnc-vcs-info.h
+gnc-scm-info.h: _gnc-scm-info.h
+	-if [ ! -f gnc-scm-info.h ]; then cp _gnc-scm-info.h gnc-scm-info.h; fi
+	-cmp -s _gnc-scm-info.h gnc-scm-info.h || cp _gnc-scm-info.h gnc-scm-info.h
+	-rm -f _gnc-scm-info.h
 
-_gnc-vcs-info.h: Makefile
-	@vcs_info=`${top_srcdir}/util/gnc-vcs-info -r ${top_srcdir}` ; \
+_gnc-scm-info.h: Makefile
+	@scm_info=`${top_srcdir}/util/gnc-scm-info -r ${top_srcdir}` ; \
 	if [ $$? = 0 ] ; then \
-		if [ -z "$$vcs_info" ] ; then \
-			echo "gnc-vcs-info failed.  figure out why." ; \
+		if [ -z "$$scm_info" ] ; then \
+			echo "gnc-scm-info failed.  figure out why." ; \
 			echo "can't determine svn/svk/git/bzr revision from ${top_srcdir}." ; \
 			exit 1 ; \
 		fi ; \
-		echo "/* Autogenerated. Do not change. */"    > _gnc-vcs-info.h ; \
-		echo "#define GNUCASH_VCS_REV \"$$vcs_info\"" >> _gnc-vcs-info.h ; \
+		echo "/* Autogenerated. Do not change. */"    > _gnc-scm-info.h ; \
+		echo "#define GNUCASH_SCM_REV \"$$scm_info\"" >> _gnc-scm-info.h ; \
 	else \
-		if [ -r $(srcdir)/gnc-vcs-info.h ] ; then \
-			cp $(srcdir)/gnc-vcs-info.h _gnc-vcs-info.h ; \
+		if [ -r $(srcdir)/gnc-scm-info.h ] ; then \
+			cp $(srcdir)/gnc-scm-info.h _gnc-scm-info.h ; \
 		else \
 			echo "You're building from svn/svk/git/bzr...  But your build system is broken" ; \
 			echo "Don't do that.   Complain to your build-system creator." ; \

Modified: gnucash/trunk/src/engine/Makefile.am
===================================================================
--- gnucash/trunk/src/engine/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/engine/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -188,7 +188,7 @@
 
 noinst_DATA = .scm-links
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 
 # The generated file depends on various libqof headers. Out of
 # laziness I only include a few here - more might be needed

Modified: gnucash/trunk/src/gnc/main.cpp
===================================================================
--- gnucash/trunk/src/gnc/main.cpp	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/gnc/main.cpp	2012-11-01 10:35:34 UTC (rev 22476)
@@ -71,8 +71,8 @@
 
 #define APP_GNUCASH "/apps/gnucash"
 
-/* GNUCASH_VCS is defined whenever we're building from an svn/svk/git/bzr tree */
-#ifdef GNUCASH_VCS
+/* GNUCASH_SCM is defined whenever we're building from an svn/svk/git/bzr tree */
+#ifdef GNUCASH_SCM
 static int is_development_version = TRUE;
 #else
 static int is_development_version = FALSE;

Modified: gnucash/trunk/src/gnc-module/Makefile.am
===================================================================
--- gnucash/trunk/src/gnc-module/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/gnc-module/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -29,7 +29,7 @@
 
 noinst_DATA = .scm-links
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 swig-gnc-module.c: gnc-module.i ${top_srcdir}/src/base-typemaps.i
 	$(SWIG) -guile $(SWIG_ARGS) -Linkage module \
 	-I${top_srcdir}/src -o $@ $<

Modified: gnucash/trunk/src/gnc-module/test/mod-bar/Makefile.am
===================================================================
--- gnucash/trunk/src/gnc-module/test/mod-bar/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/gnc-module/test/mod-bar/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -22,7 +22,7 @@
   $(GUILE_LIBS) \
   $(GLIB_LIBS)
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 swig-bar.c: bar.i
 	$(SWIG) -guile $(SWIG_ARGS) -Linkage module -o $@ $<
 endif

Modified: gnucash/trunk/src/gnc-module/test/mod-baz/Makefile.am
===================================================================
--- gnucash/trunk/src/gnc-module/test/mod-baz/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/gnc-module/test/mod-baz/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -26,7 +26,7 @@
   $(GUILE_LIBS) \
   $(GLIB_LIBS)
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 swig-baz.c: baz.i
 	$(SWIG) -guile $(SWIG_ARGS) -Linkage module -o $@ $<
 endif

Modified: gnucash/trunk/src/gnc-module/test/mod-foo/Makefile.am
===================================================================
--- gnucash/trunk/src/gnc-module/test/mod-foo/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/gnc-module/test/mod-foo/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -27,7 +27,7 @@
   foo.i \
   gnucash/foo.scm
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 swig-foo.c: foo.i
 	$(SWIG) -guile $(SWIG_ARGS) -Linkage module -o $@ $<
 endif

Modified: gnucash/trunk/src/gnome/Makefile.am
===================================================================
--- gnucash/trunk/src/gnome/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/gnome/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -98,7 +98,7 @@
   window-reconcile.h \
   window-autoclear.h
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 swig-gnome.c: gnome.i dialog-progress.h ${top_srcdir}/src/base-typemaps.i
 	$(SWIG) -guile $(SWIG_ARGS) -Linkage module \
 	-I${top_srcdir}/src -o $@ $<

Modified: gnucash/trunk/src/gnome-utils/Makefile.am
===================================================================
--- gnucash/trunk/src/gnome-utils/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/gnome-utils/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -212,7 +212,7 @@
   libgncmod_gnome_utils_la_LIBADD += -lX11
 endif
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 swig-gnome-utils.c: gnome-utils.i \
                     ${top_srcdir}/src/base-typemaps.i
 	$(SWIG) -guile $(SWIG_ARGS) -Linkage module \

Modified: gnucash/trunk/src/gnome-utils/gnc-main-window.c
===================================================================
--- gnucash/trunk/src/gnome-utils/gnc-main-window.c	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/gnome-utils/gnc-main-window.c	2012-11-01 10:35:34 UTC (rev 22476)
@@ -4122,21 +4122,21 @@
     authors = get_file_strsplit("AUTHORS");
     documenters = get_file_strsplit("DOCUMENTERS");
     license = get_file("LICENSE");
-#ifdef GNUCASH_VCS
+#ifdef GNUCASH_SCM
     /* Development version */
     /* Translators: 1st %s is a fixed message, which is translated independently;
-                    2nd %s is the vcs type (svn/svk/git/bzr);
-                    3rd %s is the vcs revision number;
+                    2nd %s is the scm type (svn/svk/git/bzr);
+                    3rd %s is the scm revision number;
                     4th %s is the build date */
     message = g_strdup_printf(_("%s\nThis copy was built from %s rev %s on %s."),
-                              fixed_message, GNUCASH_VCS, GNUCASH_VCS_REV,
+                              fixed_message, GNUCASH_SCM, GNUCASH_SCM_REV,
                               GNUCASH_BUILD_DATE);
 #else
     /* Translators: 1st %s is a fixed message, which is translated independently;
-                    2nd %s is the vcs (svn/svk/git/bzr) revision number;
+                    2nd %s is the scm (svn/svk/git/bzr) revision number;
                     3rd %s is the build date */
     message = g_strdup_printf(_("%s\nThis copy was built from rev %s on %s."),
-                              fixed_message, GNUCASH_VCS_REV, GNUCASH_BUILD_DATE);
+                              fixed_message, GNUCASH_SCM_REV, GNUCASH_BUILD_DATE);
 #endif
     gtk_show_about_dialog
     (GTK_WINDOW (window),

Modified: gnucash/trunk/src/gnome-utils/gnc-splash.c
===================================================================
--- gnucash/trunk/src/gnome-utils/gnc-splash.c	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/gnome-utils/gnc-splash.c	2012-11-01 10:35:34 UTC (rev 22476)
@@ -85,22 +85,22 @@
     frame = gtk_frame_new (NULL);
     vbox = gtk_vbox_new (FALSE, 3);
     hbox = gtk_hbox_new (FALSE, 3);
-#ifdef GNUCASH_VCS
+#ifdef GNUCASH_SCM
     /* Development version */
     /* Translators: 1st %s is the GnuCash version (eg 2.4.11);
-                    2nd %s is the vcs type (svn/svk/git/bzr);
-                    3rd %s is the vcs revision number;
+                    2nd %s is the scm type (svn/svk/git/bzr);
+                    3rd %s is the scm revision number;
                     4th %s is the build date */
     ver_string = g_strdup_printf(_("Version: GnuCash-%s %s (rev %s built %s)"),
-                                 VERSION, GNUCASH_VCS, GNUCASH_VCS_REV,
+                                 VERSION, GNUCASH_SCM, GNUCASH_SCM_REV,
                                  GNUCASH_BUILD_DATE);
 #else
     /* Dist Tarball */
     /* Translators: 1st %s is the GnuCash version (eg 2.4.11);
-                    2nd %s is the vcs (svn/svk/git/bzr) revision number;
+                    2nd %s is the scm (svn/svk/git/bzr) revision number;
                     3rd %s is the build date */
     ver_string = g_strdup_printf(_("Version: GnuCash-%s (rev %s built %s)"),
-                                 VERSION, GNUCASH_VCS_REV, GNUCASH_BUILD_DATE);
+                                 VERSION, GNUCASH_SCM_REV, GNUCASH_BUILD_DATE);
 #endif
 
     version = gtk_label_new(NULL);

Modified: gnucash/trunk/src/html/Makefile.am
===================================================================
--- gnucash/trunk/src/html/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/html/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -61,7 +61,7 @@
   ${GUILE_LIBS} \
   ${REGEX_LIBS}
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 swig-gnc-html.c: gnc-html.i gnc-html.h \
                     ${top_srcdir}/src/base-typemaps.i
 	$(SWIG) -guile $(SWIG_ARGS) -Linkage module \

Modified: gnucash/trunk/src/optional/python-bindings/Makefile.am
===================================================================
--- gnucash/trunk/src/optional/python-bindings/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/optional/python-bindings/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -37,7 +37,7 @@
   ${top_builddir}/src/libqof/qof/libgnc-qof.la \
   ${top_builddir}/src/gnc-module/libgnc-module.la \
   ${top_builddir}/src/engine/libgncmod-engine.la
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 _gnucash_core_c_includes= \
 	${top_builddir}/config.h \
 	${top_srcdir}/src/libqof/qof/qofsession.h \

Modified: gnucash/trunk/src/pixmaps/Makefile.am
===================================================================
--- gnucash/trunk/src/pixmaps/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/pixmaps/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -78,7 +78,7 @@
 gncscalableicondir = ${datadir}/icons/hicolor/scalable/apps
 gncscalableicon_DATA = scalable/gnucash-icon.svg
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 256x256/gnucash-icon.png: gnucash-icon-256x256.png
 	-mkdir -p 256x256
 	cp ${srcdir}/gnucash-icon-256x256.png 256x256/gnucash-icon.png
@@ -161,7 +161,7 @@
   ${gncscalableicon_DATA}
 
 # Only clean up if we're building from svn/svk/git/bzr
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 clean-local:
 	-rm -rf 256x256 128x128 96x96 64x64 48x48 32x32 24x24 22x22 16x16 scalable
 endif

Modified: gnucash/trunk/src/report/report-gnome/Makefile.am
===================================================================
--- gnucash/trunk/src/report/report-gnome/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/report/report-gnome/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -51,7 +51,7 @@
   ${GCONF_LIBS} \
   ${GLIB_LIBS}
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 swig-report-gnome.c: report-gnome.i ${top_srcdir}/src/base-typemaps.i
 	$(SWIG) -guile $(SWIG_ARGS) -Linkage module \
 	-I${top_srcdir}/src -o $@ $<

Modified: gnucash/trunk/src/report/report-system/Makefile.am
===================================================================
--- gnucash/trunk/src/report/report-system/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/report/report-system/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -20,7 +20,7 @@
   ${GLIB_LIBS} \
   ${GTK_LIBS}
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 swig-report-system.c: report-system.i ${top_srcdir}/src/base-typemaps.i
 	$(SWIG) -guile $(SWIG_ARGS) -Linkage module \
 	-I${top_srcdir}/src -o $@ $<

Modified: gnucash/trunk/src/test-core/Makefile.am
===================================================================
--- gnucash/trunk/src/test-core/Makefile.am	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/test-core/Makefile.am	2012-11-01 10:35:34 UTC (rev 22476)
@@ -23,7 +23,7 @@
 libtest_core_la_LDFLAGS = \
   -rpath ${exec-prefix}/lib
 
-if BUILDING_FROM_VCS
+if BUILDING_FROM_SCM
 swig-unittest-support-guile.c: unittest-support.i $(top_srcdir)/src/base-typemaps.i
 	$(SWIG) -guile $(SWIG_ARGS) -Linkage module \
 	-I${top_srcdir}/src \

Copied: gnucash/trunk/util/gnc-scm-info (from rev 22475, gnucash/trunk/util/gnc-vcs-info)
===================================================================
--- gnucash/trunk/util/gnc-scm-info	                        (rev 0)
+++ gnucash/trunk/util/gnc-scm-info	2012-11-01 10:35:34 UTC (rev 22476)
@@ -0,0 +1,178 @@
+#!/bin/sh
+#
+# Usage:
+#   gnc-vcs-info -r <srcdir>
+#   gnc-vcs-info -t <srcdir>
+#
+# With -r prints the revision number to stdout and exits 0 on success
+# With -t prints the vcs type that was detected to stdout and exits 0
+#         on success.
+#
+# Exits with errorcode 1 if we're not in an bzr, svn, svk or git checkout
+#
+# Written By:  Derek Atkins <derek at ihtfp.com>
+# Updated By:  Geert Janssens <geert at kobaltwit.be>
+#
+# $Id$
+
+# Default string to return if not invoked properly
+usage="Usage: $0 -r <srcdir>
+       $0 -t <srcdir>"
+
+# Print an error message and then exit
+my_die()
+{
+  echo "$1"
+  exit 1
+}
+
+if [ "$BUILDING_FROM_SVN" = "0" -o \
+     "$BUILDING_FROM_SVN" = "no" -o \
+     "$BUILDING_FROM_SVN" = "false" ]; then
+  # Something outside of the Gnucash build system knows that we
+  # are NOT building from svn, svk or git checkout.
+  # We should believe it (needed by packagers that maintain the
+  # packaging code in svn, svk or git too)
+  echo "Environment variable BUILDING_FROM_SVN=$BUILDING_FROM_SVN" >&2
+  exit 1
+fi
+
+# Make sure we have a srcdir
+[ -n "$1" ] || my_die "$usage"
+[ -n "$2" ] || my_die "$usage"
+[ -d "$2" ] || my_die "$0: $2: not a directory"
+
+
+if [ "$1" = "-t" ]
+then
+  request="type"
+elif [ "$1" = "-r" ]
+then
+  request="revision"
+else
+  my_die "$usage"
+fi
+
+srcdir=$2
+
+# Find the real srcdir.
+# This handles the case of a symlink (lndir) tree
+# $real_srcdir will hold the actual source dir
+if test -h "$srcdir"/Makefile.am
+then 
+  tmp_srcdir=`readlink "$srcdir"/Makefile.am`
+  real_srcdir="$srcdir/`dirname ${tmp_srcdir}`"
+else
+  real_srcdir="$srcdir"
+fi
+
+# Test if this code is an SVN Checkout
+#   If this is an svn checkout we assume you have svnversion!
+if test -d "${real_srcdir}"/.svn
+then
+  # If we're only interested in the vcs type, then we're done here
+  if [ "$request" = "type" ]
+  then
+    echo "svn"
+    exit 0
+  fi
+
+  # svnversion without options returns the most recent revision in the repo
+  # at the time of the last svn update/checkout even if that revision
+  # didn't hold any changes in the current path. Not very useful as a
+  # reference. Better is to ask for the last changed revision with -c.
+  # BUT: -c option for some reason always considers svn working copy
+  # as having mixed sources. We're only interested in the last part so
+  # we strip the beginning revision if it's there.
+  # As a result if your WC really has mixed sources, that will not be
+  # visible in the version number...
+  svn_mixed_version=$(svnversion -c "$real_srcdir")
+  echo ${svn_mixed_version#*:}
+  exit $?
+fi
+
+# If we get here then this is NOT an svn checkout.
+
+# Maybe it's git?
+real_gitdir="${real_srcdir}"/.git
+if test -d "${real_gitdir}"
+then
+  # If we're only interested in the vcs type, then we're done here
+  if [ "$request" = "type" ]
+  then
+    echo "git"
+    exit 0
+  fi
+
+  # The windows build uses environment variable $GIT_CMD to invoke git (adding git
+  # to the PATH in Windows results in a build failure).
+  # So for platform independence, use GIT_CMD for all
+  [ -n "$GIT_CMD" ] || GIT_CMD=git
+  githead=`"$GIT_CMD" --git-dir "${real_gitdir}" log -1 --pretty=format:"%h" HEAD 2>/dev/null`  # short hash only
+  if test $? = 0 ; then
+    /bin/echo -n $githead
+    # Add a "+" to the hash if there deleted or modified files (not excluded by .gitignore and friends)
+    # "Ignores" untracked files
+    # [ $("$GIT_CMD" --git-dir "${real_gitdir}" ls-files -dkm 2>/dev/null | wc -l) -gt 0 ] && /bin/echo -n "+"
+    # Includes untracked files
+    [ $("$GIT_CMD" --git-dir "${real_gitdir}" ls-files -dkmo --exclude-standard 2>/dev/null | wc -l) -gt 0 ] && /bin/echo -n "+"
+    echo
+    exit 0
+  else
+    exit 1
+  fi
+fi
+
+if test -d "${real_srcdir}"/.bzr ;
+then
+  # If we're only interested in the vcs type, then we're done here
+  if [ "$request" = "type" ]
+  then
+    echo "bzr"
+    exit 0
+  fi
+
+  bzrhead=`(cd "${real_srcdir}"; bzr version-info --custom --template='{revno}\n')`
+  if test $? = 0 ; then
+    echo "$bzrhead";
+    exit 0
+  else
+    exit 1
+  fi
+fi
+
+if test $OSTYPE -a $OSTYPE = "msys";
+then
+  svk_name="svk.bat"
+  svk_cmd="cmd \/c svk"
+else
+  svk_name="svk"
+  svk_cmd="svk"
+fi
+
+# Maybe it's SVK?  First, check if we've got 'svk' in the path.  If not,
+# then exit with an error code of 1..
+which $svk_name >/dev/null 2>&1
+if test $? != 0 ; then exit 1 ; fi
+
+# Okay, we have 'svk'.  Now see if $real_srcdir is an svk checkout
+# Note that the 'echo n' is to protect against having svk installed
+# without having configured the depotmap.
+svkinfo=`echo n | $svk_cmd info "$real_srcdir" 2>&1`
+if test $? != 0 ; then exit 1 ; fi
+
+# If we got here, then $real_srcdir is an svk checkout.
+# If we're only interested in the vcs type, then we're done here
+if [ "$request" = "type" ]
+then
+  echo "bzr"
+  exit 0
+fi
+
+# Parse out the revision info, print it out, and then output 0.  Just combine
+# all the revision numbers into a single string by combining them
+# with periods.
+svkinfo=`$svk_cmd info "$real_srcdir" | grep Rev | head -5 | sed -e 's/^.* \([0-9:]*\)$/\1/'`
+echo $svkinfo | sed -e 's/ /./g'
+
+exit 0

Deleted: gnucash/trunk/util/gnc-vcs-info
===================================================================
--- gnucash/trunk/util/gnc-vcs-info	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/util/gnc-vcs-info	2012-11-01 10:35:34 UTC (rev 22476)
@@ -1,178 +0,0 @@
-#!/bin/sh
-#
-# Usage:
-#   gnc-vcs-info -r <srcdir>
-#   gnc-vcs-info -t <srcdir>
-#
-# With -r prints the revision number to stdout and exits 0 on success
-# With -t prints the vcs type that was detected to stdout and exits 0
-#         on success.
-#
-# Exits with errorcode 1 if we're not in an bzr, svn, svk or git checkout
-#
-# Written By:  Derek Atkins <derek at ihtfp.com>
-# Updated By:  Geert Janssens <geert at kobaltwit.be>
-#
-# $Id$
-
-# Default string to return if not invoked properly
-usage="Usage: $0 -r <srcdir>
-       $0 -t <srcdir>"
-
-# Print an error message and then exit
-my_die()
-{
-  echo "$1"
-  exit 1
-}
-
-if [ "$BUILDING_FROM_SVN" = "0" -o \
-     "$BUILDING_FROM_SVN" = "no" -o \
-     "$BUILDING_FROM_SVN" = "false" ]; then
-  # Something outside of the Gnucash build system knows that we
-  # are NOT building from svn, svk or git checkout.
-  # We should believe it (needed by packagers that maintain the
-  # packaging code in svn, svk or git too)
-  echo "Environment variable BUILDING_FROM_SVN=$BUILDING_FROM_SVN" >&2
-  exit 1
-fi
-
-# Make sure we have a srcdir
-[ -n "$1" ] || my_die "$usage"
-[ -n "$2" ] || my_die "$usage"
-[ -d "$2" ] || my_die "$0: $2: not a directory"
-
-
-if [ "$1" = "-t" ]
-then
-  request="type"
-elif [ "$1" = "-r" ]
-then
-  request="revision"
-else
-  my_die "$usage"
-fi
-
-srcdir=$2
-
-# Find the real srcdir.
-# This handles the case of a symlink (lndir) tree
-# $real_srcdir will hold the actual source dir
-if test -h "$srcdir"/Makefile.am
-then 
-  tmp_srcdir=`readlink "$srcdir"/Makefile.am`
-  real_srcdir="$srcdir/`dirname ${tmp_srcdir}`"
-else
-  real_srcdir="$srcdir"
-fi
-
-# Test if this code is an SVN Checkout
-#   If this is an svn checkout we assume you have svnversion!
-if test -d "${real_srcdir}"/.svn
-then
-  # If we're only interested in the vcs type, then we're done here
-  if [ "$request" = "type" ]
-  then
-    echo "svn"
-    exit 0
-  fi
-
-  # svnversion without options returns the most recent revision in the repo
-  # at the time of the last svn update/checkout even if that revision
-  # didn't hold any changes in the current path. Not very useful as a
-  # reference. Better is to ask for the last changed revision with -c.
-  # BUT: -c option for some reason always considers svn working copy
-  # as having mixed sources. We're only interested in the last part so
-  # we strip the beginning revision if it's there.
-  # As a result if your WC really has mixed sources, that will not be
-  # visible in the version number...
-  svn_mixed_version=$(svnversion -c "$real_srcdir")
-  echo ${svn_mixed_version#*:}
-  exit $?
-fi
-
-# If we get here then this is NOT an svn checkout.
-
-# Maybe it's git?
-real_gitdir="${real_srcdir}"/.git
-if test -d "${real_gitdir}"
-then
-  # If we're only interested in the vcs type, then we're done here
-  if [ "$request" = "type" ]
-  then
-    echo "git"
-    exit 0
-  fi
-
-  # The windows build uses environment variable $GIT_CMD to invoke git (adding git
-  # to the PATH in Windows results in a build failure).
-  # So for platform independence, use GIT_CMD for all
-  [ -n "$GIT_CMD" ] || GIT_CMD=git
-  githead=`"$GIT_CMD" --git-dir "${real_gitdir}" log -1 --pretty=format:"%h" HEAD 2>/dev/null`  # short hash only
-  if test $? = 0 ; then
-    /bin/echo -n $githead
-    # Add a "+" to the hash if there deleted or modified files (not excluded by .gitignore and friends)
-    # "Ignores" untracked files
-    # [ $("$GIT_CMD" --git-dir "${real_gitdir}" ls-files -dkm 2>/dev/null | wc -l) -gt 0 ] && /bin/echo -n "+"
-    # Includes untracked files
-    [ $("$GIT_CMD" --git-dir "${real_gitdir}" ls-files -dkmo --exclude-standard 2>/dev/null | wc -l) -gt 0 ] && /bin/echo -n "+"
-    echo
-    exit 0
-  else
-    exit 1
-  fi
-fi
-
-if test -d "${real_srcdir}"/.bzr ;
-then
-  # If we're only interested in the vcs type, then we're done here
-  if [ "$request" = "type" ]
-  then
-    echo "bzr"
-    exit 0
-  fi
-
-  bzrhead=`(cd "${real_srcdir}"; bzr version-info --custom --template='{revno}\n')`
-  if test $? = 0 ; then
-    echo "$bzrhead";
-    exit 0
-  else
-    exit 1
-  fi
-fi
-
-if test $OSTYPE -a $OSTYPE = "msys";
-then
-  svk_name="svk.bat"
-  svk_cmd="cmd \/c svk"
-else
-  svk_name="svk"
-  svk_cmd="svk"
-fi
-
-# Maybe it's SVK?  First, check if we've got 'svk' in the path.  If not,
-# then exit with an error code of 1..
-which $svk_name >/dev/null 2>&1
-if test $? != 0 ; then exit 1 ; fi
-
-# Okay, we have 'svk'.  Now see if $real_srcdir is an svk checkout
-# Note that the 'echo n' is to protect against having svk installed
-# without having configured the depotmap.
-svkinfo=`echo n | $svk_cmd info "$real_srcdir" 2>&1`
-if test $? != 0 ; then exit 1 ; fi
-
-# If we got here, then $real_srcdir is an svk checkout.
-# If we're only interested in the vcs type, then we're done here
-if [ "$request" = "type" ]
-then
-  echo "bzr"
-  exit 0
-fi
-
-# Parse out the revision info, print it out, and then output 0.  Just combine
-# all the revision numbers into a single string by combining them
-# with periods.
-svkinfo=`$svk_cmd info "$real_srcdir" | grep Rev | head -5 | sed -e 's/^.* \([0-9:]*\)$/\1/'`
-echo $svkinfo | sed -e 's/ /./g'
-
-exit 0



More information about the gnucash-changes mailing list
--- gnucash/trunk/src/bin/gnucash-bin.c	2012-10-31 21:38:49 UTC (rev 22475)
+++ gnucash/trunk/src/bin/gnucash-bin.c	2012-11-01 10:35:34 UTC (rev 22476)
@@ -65,8 +65,8 @@
 #  include <Foundation/Foundation.h>
 #endif
 
 /* GNUCASH_VCS is defined whenever we're building from an svn/svk/git/bzr tree */
 #ifdef GNUCASH_VCS
 static int is_development_version = TRUE;
 #else
 static int is_development_version = FALSE;
@@ -527,11 +527,11 @@
             fixed_message = g_strdup_printf(_("GnuCash %s development version"), VERSION);
 
             /* Translators: 1st %s is a fixed message, which is translated independently;
-                            2nd %s is the vcs type (svn/svk/git/bzr);
-                            3rd %s is the vcs revision number;
+                            2nd %s is the scm type (svn/svk/git/bzr);
+                            3rd %s is the scm revision number;
                             4th %s is the build date */
             g_print ( _("%s\nThis copy was built from %s rev %s on %s."),
-                      fixed_message, GNUCASH_VCS, GNUCASH_VCS_REV,
+                      fixed_message, GNUCASH_SCM, GNUCASH_SCM_REV,
                       GNUCASH_BUILD_DATE );
         }
         else
@@ -539,10 +539,10 @@
             fixed_message = g_strdup_printf(_("GnuCash %s"), VERSION);
 
             /* Translators: 1st %s is a fixed message, which is translated independently;
-                            2nd %s is the vcs (svn/svk/git/bzr) revision number;
+                            2nd %s is the scm (svn/svk/git/bzr) revision number;
                             3rd %s is the build date */
             g_print ( _("%s\nThis copy was built from rev %s on %s."),
-                      fixed_message, GNUCASH_VCS_REV, GNUCASH_BUILD_DATE );
+                      fixed_message, GNUCASH_SCM_REV, GNUCASH_BUILD_DATE );
         }
         g_print("\n");
         g_free (fixed_message);
@@ -65,8 +65,8 @@
 #endif
 
-/* GNUCASH_VCS is defined whenever we're building from an svn/svk/git/bzr tree */
-#ifdef GNUCASH_VCS
+/* GNUCASH_SCM is defined whenever we're building from an svn/svk/git/bzr tree */
+#ifdef GNUCASH_SCM
 static int is_development_version = TRUE;
 #else

Modified: gnucash/trunk/src/core-utils/Makefile.am
===================================================================